#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: fontpage
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION   : 2009-12-12 
# BUILD-ONLY DEPS	: -
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="fontpage"
VERSION="2.5"
ARCH="i686"
CPU="i686"
BUILD="64.1"
EXT="txz"
HOMEPAGE="http://www.pcbypaul.com/software/FONTpage.shtml"
SRCLNK="http://www.pcbypaul.com/software/dl/fontpage-2.5.tar.bz2"
DESCRIPTION=""
DOCS="changelog COPYING INSTALL README"
ADDSRC="fontpage.png"
INCSRC="fontpage.png"
ADDDEP="fontconfig,gtk+2,pango,pygtk,python"
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

# Repackaging
install -dv $PKGDIR/usr/bin
install -dv $PKGDIR/usr/share/$NAME
cp -a fontpage.py locale $PKGDIR/usr/share/$NAME
cd $PKGDIR/usr/bin
ln -s ../share/$NAME/fontpage.py $NAME
cd $SRCDIR

# Icon
install -Dv $CWD/$NAME.png $PKGDIR/usr/share/icons/hicolor/48x48/apps/$NAME.png

# Desktop entry
install -dv $PKGDIR/usr/share/applications
cat > $PKGDIR/usr/share/applications/$NAME.desktop << EOF
[Desktop Entry]
Name=FONTpage
Comment=Font viewer and manager tool
Exec=fontpage
Icon=fontpage
Type=Application
Categories=Utility;Graphics
Terminal=false
StartupNotify=true
Encoding=UTF-8
EOF

# Docs, man, info
install -dv $PKGDIR/usr/doc/$NAME-$VERSION
install -v $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: FONTpage is a pyGTK application with which you can view truetype 
$NAME: fonts on a system using fontconfig, change font face, size, 
$NAME: foregound and background color while viewing the fonts, save a
$NAME: snapshot of your view to a png image, install and delete fonts for
$NAME: the current user.
$NAME: In general, it is a handy tool view fonts and styles quickly or to 
$NAME: make "logo" graphics for use in web pages.
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall

#~ ===================================================================== 

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
echo $SRCLNK > $PKG.src
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
rm -rf $SRCDIR
rm -rf $PKGDIR

### Done. Ciao!
